@@ -4,8 +4,11 @@ Base class for sending a specific type of KNX/IP Packet to a KNX/IP device and w
 Will report if the corresponding answer was not received.
 """
 import asyncio
+import logging
 
-from xknx.knxip import ErrorCode
+from xknx.knxip import ErrorCode, KNXIPFrame
+
+logger = logging.getLogger("xknx.log")
 
 
 class RequestResponse:
@@ -23,7 +26,7 @@ class RequestResponse:
         self.timeout_in_seconds = timeout_in_seconds
         self.timeout_handle = None
 
-    def create_knxipframe(self):
+    def create_knxipframe(self) -> KNXIPFrame:
         """Create KNX/IP Frame object to be sent to device."""
         raise NotImplementedError("create_knxipframe has to be implemented")
 
@@ -40,14 +43,12 @@ class RequestResponse:
 
     async def send_request(self):
         """Build knxipframe (within derived class) and send via UDP."""
-        knxipframe = self.create_knxipframe()
-        knxipframe.normalize()
-        self.udpclient.send(knxipframe)
+        self.udpclient.send(self.create_knxipframe())
 
     def response_rec_callback(self, knxipframe, _):
         """Verify and handle knxipframe. Callback from internal udpclient."""
         if not isinstance(knxipframe.body, self.awaited_response_class):
-            self.xknx.logger.warning("Could not understand knxipframe")
+            logger.warning("Could not understand knxipframe")
             return
         self.response_received_or_timeout.set()
         if knxipframe.body.status_code == ErrorCode.E_NO_ERROR:
@@ -61,7 +62,7 @@ class RequestResponse:
 
     def on_error_hook(self, knxipframe):
         """Do something after having received error within given time. May be overwritten in derived class."""
-        self.xknx.logger.debug(
+        logger.debug(
             "Error: KNX bus responded to request of type '%s' with error in '%s': %s",
             self.__class__.__name__,
             self.awaited_response_class.__name__,
@@ -70,7 +71,7 @@ class RequestResponse:
 
     def timeout(self):
         """Handle timeout for not having received expected knxipframe."""
-        self.xknx.logger.debug(
+        logger.debug(
             "Error: KNX bus did not respond in time (%s secs) to request of type '%s'",
             self.timeout_in_seconds,
             self.__class__.__name__,
@@ -79,9 +80,8 @@ class RequestResponse:
 
     async def start_timeout(self):
         """Start timeout."""
-        self.timeout_handle = self.xknx.loop.call_later(
-            self.timeout_in_seconds, self.timeout
-        )
+        loop = asyncio.get_running_loop()
+        self.timeout_handle = loop.call_later(self.timeout_in_seconds, self.timeout)
 
     async def stop_timeout(self):
         """Stop timeout."""
