@@ -17,7 +17,7 @@ from xknx.telegram import PhysicalAddress
 from .knxip_enum import DIBServiceFamily, DIBTypeCode, KNXMedium
 
 
-class DIB():
+class DIB:
     """
     Base class for DIB (Description Information Block).
 
@@ -94,9 +94,9 @@ class DIBGeneric(DIB):
 
     def __str__(self):
         """Return object as readable string."""
-        return '<DIB dtc="{0}" data="{1}" />'.format(
-            self.dtc,
-            ', '.join('0x%02x' % i for i in self.data))
+        return '<DIB dtc="{}" data="{}" />'.format(
+            self.dtc, ", ".join("0x%02x" % i for i in self.data)
+        )
 
 
 class DIBSuppSVCFamilies(DIB):
@@ -114,8 +114,7 @@ class DIBSuppSVCFamilies(DIB):
 
         def __str__(self):
             """Return object as readable string."""
-            return '<Family name="{0}" version="{1}" />' \
-                .format(self.name, self.version)
+            return f'<Family name="{self.name}" version="{self.version}" />'
 
         def __eq__(self, other):
             """Equal operator."""
@@ -135,7 +134,7 @@ class DIBSuppSVCFamilies(DIB):
 
     def calculated_length(self):
         """Get length of KNX/IP object."""
-        return len(self.families)*2+2
+        return len(self.families) * 2 + 2
 
     def from_knx(self, raw):
         """Parse/deserialize from KNX/IP raw data."""
@@ -147,16 +146,16 @@ class DIBSuppSVCFamilies(DIB):
         if DIBTypeCode(raw[1]) != DIBTypeCode.SUPP_SVC_FAMILIES:
             raise CouldNotParseKNXIP("DIB is no device info")
 
-        for i in range(0, int((length-2)/2)):
-            name = DIBServiceFamily(raw[i*2+2])
-            version = raw[i*2+3]
+        for i in range(0, int((length - 2) / 2)):
+            name = DIBServiceFamily(raw[i * 2 + 2])
+            version = raw[i * 2 + 3]
             self.families.append(DIBSuppSVCFamilies.Family(name, version))
         return length
 
     def to_knx(self):
         """Serialize to KNX/IP raw data."""
         data = []
-        data.append(len(self.families)*2+2)
+        data.append(len(self.families) * 2 + 2)
         data.append(DIBTypeCode.SUPP_SVC_FAMILIES.value)
         for family in self.families:
             data.append(family.name.value)
@@ -165,9 +164,11 @@ class DIBSuppSVCFamilies(DIB):
 
     def __str__(self):
         """Return object as readable string."""
-        return '<DIBSuppSVCFamilies families="[{0}]" />' \
-            .format(", ".join("{0} version: {1}".format(
-                family.name, family.version) for family in self.families))
+        return '<DIBSuppSVCFamilies families="[{}]" />'.format(
+            ", ".join(
+                f"{family.name} version: {family.version}" for family in self.families
+            )
+        )
 
 
 class DIBDeviceInformation(DIB):
@@ -206,19 +207,19 @@ class DIBDeviceInformation(DIB):
         self.knx_medium = KNXMedium(raw[2])
         # last bit of device_status. All other bits are unused
         self.programming_mode = bool(raw[3])
-        self.individual_address = \
-            PhysicalAddress((raw[4], raw[5]))
-        installation_project_identifier = raw[6]*256+raw[7]
+        self.individual_address = PhysicalAddress((raw[4], raw[5]))
+        installation_project_identifier = raw[6] * 256 + raw[7]
         self.project_number = installation_project_identifier >> 4
         self.installation_number = installation_project_identifier & 15
-        self.serial_number = ":".join('%02x' % i for i in raw[8:14])
-        self.multicast_address = ".".join('%i' % i for i in raw[14:18])
-        self.mac_address = ":".join('%02x' % i for i in raw[18:24])
-        self.name = "".join(map(chr, raw[24:54])).rstrip('\0')
+        self.serial_number = ":".join("%02x" % i for i in raw[8:14])
+        self.multicast_address = ".".join("%i" % i for i in raw[14:18])
+        self.mac_address = ":".join("%02x" % i for i in raw[18:24])
+        self.name = "".join(map(chr, raw[24:54])).rstrip("\0")
         return DIBDeviceInformation.LENGTH
 
     def to_knx(self):
         """Serialize to KNX/IP raw data."""
+
         def hex_notation_to_knx(serial_number):
             """Serialize hex notation."""
             for part in serial_number.split(":"):
@@ -231,15 +232,16 @@ class DIBDeviceInformation(DIB):
 
         def str_to_knx(string, length):
             """Serialize string."""
-            if len(string) > length-1:
-                string = string[:length-1]
+            if len(string) > length - 1:
+                string = string[: length - 1]
             for char in string:
                 yield ord(char)
-            for _ in range(0, 30-len(string)):
+            for _ in range(0, 30 - len(string)):
                 yield 0x00
-        installation_project_identifier = \
-            (self.project_number * 16) + \
-            self.installation_number
+
+        installation_project_identifier = (
+            self.project_number * 16
+        ) + self.installation_number
         data = []
         data.append(DIBDeviceInformation.LENGTH)
         data.append(DIBTypeCode.DEVICE_INFO.value)
@@ -256,17 +258,25 @@ class DIBDeviceInformation(DIB):
 
     def __str__(self):
         """Return object as readable string."""
-        return '<DIBDeviceInformation ' \
-               '\n\tknx_medium="{0}" ' \
-               '\n\tprogramming_mode="{1}" ' \
-               '\n\tindividual_address="{2}" ' \
-               '\n\tinstallation_number="{3}" ' \
-               '\n\tproject_number="{4}" ' \
-               '\n\tserial_number="{5}" ' \
-               '\n\tmulticast_address="{6}" ' \
-               '\n\tmac_address="{7}" ' \
-               '\n\tname="{8}" />'.format(
-                   self.knx_medium, self.programming_mode,
-                   self.individual_address, self.installation_number,
-                   self.project_number, self.serial_number,
-                   self.multicast_address, self.mac_address, self.name)
+        return (
+            "<DIBDeviceInformation "
+            '\n\tknx_medium="{}" '
+            '\n\tprogramming_mode="{}" '
+            '\n\tindividual_address="{}" '
+            '\n\tinstallation_number="{}" '
+            '\n\tproject_number="{}" '
+            '\n\tserial_number="{}" '
+            '\n\tmulticast_address="{}" '
+            '\n\tmac_address="{}" '
+            '\n\tname="{}" />'.format(
+                self.knx_medium,
+                self.programming_mode,
+                self.individual_address,
+                self.installation_number,
+                self.project_number,
+                self.serial_number,
+                self.multicast_address,
+                self.mac_address,
+                self.name,
+            )
+        )
