@@ -4,6 +4,7 @@ Module for managing an DPT Step remote value.
 DPT 1.007.
 """
 from enum import Enum
+from typing import List
 
 from xknx.dpt import DPTBinary
 from xknx.exceptions import ConversionError, CouldNotParseTelegram
@@ -29,6 +30,7 @@ class RemoteValueStep(RemoteValue):
         feature_name="Step",
         after_update_cb=None,
         invert=False,
+        passive_group_addresses: List[str] = None,
     ):
         """Initialize remote value of KNX DPT 1.007."""
         # pylint: disable=too-many-arguments
@@ -39,6 +41,7 @@ class RemoteValueStep(RemoteValue):
             device_name=device_name,
             feature_name=feature_name,
             after_update_cb=after_update_cb,
+            passive_group_addresses=passive_group_addresses,
         )
         self.invert = invert
 
